tendril.frontend.blueprints.inventory.views module
==================================================

.. automodule:: tendril.frontend.blueprints.inventory.views
    :members:
    :undoc-members:
    :show-inheritance:
